Api

Struct Api 

pub struct Api { /* private fields */ }
Concrete API client that talks to the remote service using reqwest.

Implementations

Source

impl Api

pub fn new(auth: Auth) -> Self

Constructs a new Api client with the supplied auth settings.